Learn R Programming

aqfig (version 0.9)

kristen.colors: Sets up a color palette which is particularly appropriate for use with the scatterplot.density function

Description

This function sets up a color palette with n colors, with gradually changing hues of grey, purple, blue, green, yellow, orange, red, and brown (in this order). This palette is a particularly good choice for scatterplot.density function, for which it is the default choice.

Usage

kristen.colors(n=64)

Value

Returns n colors (in hexadecimal).

Arguments

n

Number of colors to include in palette.

Author

Original code was authored by Kristen Foley and included in the precursor to scatterplot.density. Packaged into a new function by Jenise Swall.

Details

This function calls colorRampPalette and returns n colors from this palette.

See Also