This function sets up a color palette with n colors,
with gradually changing hues of grey, purple, blue, green, yellow,
orange, red, and brown (in this order). This palette is a
particularly good choice for scatterplot.density
function, for which it is the default choice.
kristen.colors(n=64)Returns n colors (in hexadecimal).
Number of colors to include in palette.
Original code was authored by Kristen Foley and included in the
precursor to scatterplot.density. Packaged into a new
function by Jenise Swall.
This function calls colorRampPalette and returns
n colors from this palette.